==> dde-dock_5.4.10.orig.tar.xz: dde-dock-5.4.10/translations/dde-dock_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ar" version="2.1">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>الإضافة 1% غير متوافقة مع النظام.</translation>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>إزالة</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>إعدادات البلوتوث</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>ايقاف</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>إعدادات البلوتوث</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>البلوتوث</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>البلوتوث</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>إضافة تخطيط لوحة مفاتيح</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>الوقت والتاريخ</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>توقيت 12-ساعة</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>توقيت 24-ساعة</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>إعدادات الوقت</translation>
    </message>
</context>
<context>
    <name>DeviceItem</name>
    <message>
        <source>Enable network</source>
        <translation>تمكين الشبكة</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>تعطيل الشبكة</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>إعدادات الشبكة</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>هل أنت متأكد من إفراغ  %1 عناصر ؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>لا يمكن استعادة هذا الإجراء</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>جهاز غير معروف</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>مساحة غير معروفة</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>القرص</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>فصل الكل</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>المُطلق</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>النمط الحداثي</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>النمط الفعال</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>أعلى</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>أسفل</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>يسار</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>يمين</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>اﻹبقاء ظاهراً</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>الإبقاء مخفياً</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>إخفاء ذكي</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>النمط</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>الموقع</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>الحالة</translation>
    </message>
    <message>
        <source>Plugins</source>
        <translation>الإضافات</translation>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>عرض متعدد الواجهات</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>إلغاء الإرساء</translation>
    </message>
</context>
<context>
    <name>NetworkItem</name>
    <message>
        <source>Disable wired connection</source>
        <translation>تعطيل الاتصال السلكي</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>تفعيل الاتصال السلكي</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>تعطيل الاتصال اللاسلكي</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>تفعيل الاتصال اللاسلكي</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>تعطيل الشبكة</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>تمكين الشبكة</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>إعدادات الشبكة</translation>
    </message>
    <message>
        <source>Device disabled</source>
        <translation>جهاز ملغى</translation>
    </message>
    <message>
        <source>Wireless connection: %1</source>
        <translation>الاتصال اللاسلكي: 1%</translation>
    </message>
    <message>
        <source>Wired connection: %1</source>
        <translation>اتصال سلكي بـ : %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>غير متصل</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>يتصل</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>متصل لكن لا يوجد اتصال بالإنترنت</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>سلك الشبكة غير موصول</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>شبكة لاسلكية</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>شبكة سلكية</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>الشبكة</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>شبكة سلكية</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>شبكة سلكية 1%</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>لوحة المفاتيح الافتراضية</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>الطاقة</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>إعدادت الطاقة</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>السعة 1%, 2% دقيقة متبقية</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>السعة 1% ,2% ساعة 3% دقيقة متبقية</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>جاري الشحن 1%, 2% دقيقة للاكتمال</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>جاري الشحن 1%, 2% ساعة 3% دقيقة للاكتمال</translation>
    </message>
    <message>
        <source>Charged</source>
        <translation>مشحون</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>قيد الشحن %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>إظهار سطح المكتب</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>إلغاء الإرساء</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>الطاقة</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>إيقاف التشغيل</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>إسبات</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>وضع السكون</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>قفل</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>تسجيل الخروج</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>تبديل الحساب</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>إعدادت الطاقة</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>إعادة التشغيل</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>الجهاز</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>إلغاء الكتم</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>صامت</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>إعدادات الصوت</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>الصوت 1%</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>الصوت</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>المحذوفات</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>نقل  %1 ملف إلى المحذوفات</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>نقل  %1 من الملفات إلى المحذوفات </translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>فارغ</translation>
    </message>
</context>
<context>
    <name>TrayPlugin</name>
    <message>
        <source>System Tray</source>
        <translation>منطقة إعلام النظام</translation>
    </message>
</context>
<context>
    <name>WirelessList</name>
    <message>
        <source>Wireless Network</source>
        <translation>شبكة لاسلكية</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>الشبكة اللاسلكية : %1</translation>
    </message>
</context>
</TS>

==> dde-dock_5.5.86.1.orig.tar.xz: dde-dock-5.5.86.1/translations/dde-dock_ar.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ar">
<context>
    <name>AbstractPluginsController</name>
    <message>
        <source>The plugin %1 is not compatible with the system.</source>
        <translation>الإضافة 1% غير متوافقة مع النظام.</translation>
    </message>
</context>
<context>
    <name>AirplaneModeApplet</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Turn off</source>
        <translation>ايقاف</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>Airplane Mode settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AppDragWidget</name>
    <message>
        <source>Remove</source>
        <translation>إزالة</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>إعدادات البلوتوث</translation>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>ايقاف</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>تشغيل</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>إعدادات البلوتوث</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>البلوتوث</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>البلوتوث</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>إضافة تخطيط لوحة مفاتيح</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>الوقت والتاريخ</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>توقيت 12-ساعة</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>توقيت 24-ساعة</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>إعدادات الوقت</translation>
    </message>
</context>
<context>
    <name>DialogManager</name>
    <message>
        <source>Are you sure you want to empty %1 items?</source>
        <translation>هل أنت متأكد من إفراغ  %1 عناصر ؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>إلغاء</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>حذف</translation>
    </message>
    <message>
        <source>This action cannot be restored</source>
        <translation>لا يمكن استعادة هذا الإجراء</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown device</source>
        <translation>جهاز غير معروف</translation>
    </message>
    <message>
        <source>Unknown volume</source>
        <translation>مساحة غير معروفة</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>القرص</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
    <message>
        <source>Unmount all</source>
        <translation>فصل الكل</translation>
    </message>
</context>
<context>
    <name>LauncherItem</name>
    <message>
        <source>Launcher</source>
        <translation>المُطلق</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Exit Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Dock - Safe Mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The Dock is in safe mode, please exit to show it properly</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Fashion Mode</source>
        <translation>النمط الحداثي</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>النمط الفعال</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>أعلى</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>أسفل</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>يسار</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>يمين</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>اﻹبقاء ظاهراً</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>الإبقاء مخفياً</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>إخفاء ذكي</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>النمط</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>الموقع</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>الحالة</translation>
    </message>
    <message>
        <source>Dock settings</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ModuleWidget</name>
    <message>
        <source>Size</source>
        <translation>الحجم</translation>
    </message>
    <message>
        <source>Multiple Displays</source>
        <translation>شاشات متعددة</translation>
    </message>
    <message>
        <source>Plugin Area</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Select which icons appear in the Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fashion mode</source>
        <translation>النمط الحداثي</translation>
    </message>
    <message>
        <source>Efficient mode</source>
        <translation>النمط الفعال</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>النمط</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>أعلى</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>أسفل</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>يسار</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>يمين</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>الموقع</translation>
    </message>
    <message>
        <source>Keep shown</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keep hidden</source>
        <translation>اﻹبقاء مخفياً</translation>
    </message>
    <message>
        <source>Smart hide</source>
        <translation>الاخفاء الذكي</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>الحالة</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>صغير</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>كبير</translation>
    </message>
    <message>
        <source>Show Dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>On screen where the cursor is</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only on main screen</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MultitaskingPlugin</name>
    <message>
        <source>Multitasking View</source>
        <translation>عرض متعدد الواجهات</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>إلغاء الإرساء</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>لوحة المفاتيح الافتراضية</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>الإعدادات</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power</source>
        <translation>الطاقة</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>إعدادت الطاقة</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>السعة 1%, 2% دقيقة متبقية</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>السعة 1% ,2% ساعة 3% دقيقة متبقية</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>جاري الشحن 1%, 2% دقيقة للاكتمال</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>جاري الشحن 1%, 2% ساعة 3% دقيقة للاكتمال</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>قيد الشحن %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SettingsModule</name>
    <message>
        <source>Dock</source>
        <translation>الرف</translation>
        <extra-contents_path>/personalization/Dock</extra-contents_path>
    </message>
</context>
<context>
    <name>ShowDesktopPlugin</name>
    <message>
        <source>Show Desktop</source>
        <translation>إظهار سطح المكتب</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>إلغاء الإرساء</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Power</source>
        <translation>الطاقة</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>إيقاف التشغيل</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>إسبات</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>وضع السكون</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>قفل</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>تسجيل الخروج</translation>
    </message>
    <message>
        <source>Switch account</source>
        <translation>تبديل الحساب</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>إعدادت الطاقة</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>إعادة التشغيل</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Device</source>
        <translation>الجهاز</translation>
    </message>
</context>
<context>
    <name>SoundItem</name>
    <message>
        <source>Unmute</source>
        <translation>إلغاء الكتم</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>صامت</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>إعدادات الصوت</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>الصوت 1%</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>الصوت</translation>
    </message>
</context>
<context>
    <name>TrashPlugin</name>
    <message>
        <source>Trash</source>
        <translation>المحذوفات</translation>
    </message>
    <message>
        <source>Trash - %1 file</source>
        <translation>نقل  %1 ملف إلى المحذوفات</translation>
    </message>
    <message>
        <source>Trash - %1 files</source>
        <translation>نقل  %1 من الملفات إلى المحذوفات </translation>
    </message>
    <message>
        <source>Move to Trash</source>
        <translation>نقل إلى سلة المحذوفات</translation>
    </message>
</context>
<context>
    <name>TrashWidget</name>
    <message>
        <source>Open</source>
        <translation>فتح</translation>
    </message>
    <message>
        <source>Empty</source>
        <translation>فارغ</translation>
    </message>
</context>
</TS>
